@@ -17,8 +17,8 @@ package PostScript::ScheduleGrid;
 # ABSTRACT: Print a schedule in a grid format
 #---------------------------------------------------------------------
 
-our $VERSION = '0.04';
-# This file is part of PostScript-ScheduleGrid 0.04 (December 7, 2013)
+our $VERSION = '0.05';
+# This file is part of PostScript-ScheduleGrid 0.05 (August 22, 2015)
 
 use 5.010;
 use Moose;
@@ -849,9 +849,9 @@ PostScript::ScheduleGrid - Print a schedule in a grid format
 
 =head1 VERSION
 
-This document describes version 0.04 of
-PostScript::ScheduleGrid, released December 7, 2013
-as part of PostScript-ScheduleGrid version 0.04.
+This document describes version 0.05 of
+PostScript::ScheduleGrid, released August 22, 2015
+as part of PostScript-ScheduleGrid version 0.05.
 
 =head1 SYNOPSIS
 
@@ -1180,6 +1180,7 @@ This is the L<PostScript::File> object containing the grid.
 =head2 output
 
   $rpt->output($filename [, $dir]) # save to file
+  $rpt->output($filehandle)        # print to open filehandle
   $rpt->output()                   # return as string
 
 This method takes the same parameters as L<PostScript::File/output>.
@@ -1187,8 +1188,12 @@ You can pass a filename (and optional directory name) to store the
 listings in a file.  (No extension will be added to C<$filename>, so it
 should normally end in ".ps".)
 
-If you don't pass a filename, then the PostScript code is returned as
-a string.
+You can also pass an open filehandle (anything recognized by
+L<Scalar::Util/filehandle>) to print the PostScript code to that filehandle.
+The filehandle will not be closed afterwards.
+
+If you don't pass a filename or filehandle, then the PostScript code
+is returned as a string.
 
 =head1 SEE ALSO
 
@@ -1260,7 +1265,7 @@ L<< https://github.com/madsen/postscript-schedulegrid >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Christopher J. Madsen.
+This software is copyright (c) 2015 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
